==> haskell-crypto-random-0.0.9-141-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-random
version:              0.0.9
visibility:           public
id:                   crypto-random-0.0.9-JmkQkGzwVOGFu3tDjTrFCD
key:                  crypto-random-0.0.9-JmkQkGzwVOGFu3tDjTrFCD
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-random
synopsis:             Simple cryptographic random related types
description:          Simple cryptographic random related types
category:             Cryptography
abi:                  b854ffe0a433caba489aeac07580dad7
exposed:              True
exposed-modules:      Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules:
    Crypto.Random.Generator Crypto.Random.Entropy
    Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
    Crypto.Random.Entropy.RDRand

import-dirs:          /usr/lib/ghc-8.10.2/site-local/crypto-random-0.0.9
library-dirs:         /usr/lib/ghc-8.10.2/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/crypto-random-0.0.9
hs-libraries:         HScrypto-random-0.0.9-JmkQkGzwVOGFu3tDjTrFCD
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    securemem-0.1.10-BaRrlb0G3ptLAiY8uanPrD unix-2.7.2.2
    vector-0.12.1.2-Ey11gGB2S4fIXSHQgTBQEm

haddock-interfaces:
    /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock

haddock-html:         /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-random-0.0.9-143-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-random
version:              0.0.9
visibility:           public
id:                   crypto-random-0.0.9-5wfI1lQtLkgC448WzfZS32
key:                  crypto-random-0.0.9-5wfI1lQtLkgC448WzfZS32
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-random
synopsis:             Simple cryptographic random related types
description:          Simple cryptographic random related types
category:             Cryptography
abi:                  cb33864ed152f07e802f17d85f082c93
exposed:              True
exposed-modules:      Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules:
    Crypto.Random.Generator Crypto.Random.Entropy
    Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
    Crypto.Random.Entropy.RDRand

import-dirs:          /usr/lib/ghc-8.10.2/site-local/crypto-random-0.0.9
library-dirs:         /usr/lib/ghc-8.10.2/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/crypto-random-0.0.9
hs-libraries:         HScrypto-random-0.0.9-5wfI1lQtLkgC448WzfZS32
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    securemem-0.1.10-BaRrlb0G3ptLAiY8uanPrD unix-2.7.2.2
    vector-0.12.1.2-9Tv6x03Z1JF7LL7lw4fTei

haddock-interfaces:
    /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock

haddock-html:         /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
